@@ -23,5 +23,9 @@ Here are just a few of the things you can do:
   same query many times (in development or debugging)
   - queries return pandas time-series, w/ datetime indexes
   
+Be sure to install blpapi first via pip
+
+The BBG Python API can be installed through 'pip' using:
+>> python -m pip install --index-url=https://bcms.bloomberg.com/pip/simple blpapi
   
 """
